==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/admin/messages/vi/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Set as default module',
    'Always activated' => 'Luôn luôn kích hoạt',
    'Are you sure? *ALL* module data will be lost!' => 'Bạn có chắc? *TẤT CẢ* dữ liệu module sẽ bị mất!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Bạn có chắc?  *TẤT CẢ* các files và dữ liệu liên quan sẽ bị mất!',
    'Close' => 'Đóng',
    'Could not find requested module!' => 'Không thể tìm thấy module!',
    'Deactivated' => 'Hủy kích hoạt',
    'Enable module...' => 'Kích hoạt module...',
    'Enabled' => 'Đã được kích hoạt',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Ở đây bạn có thể chọn có hay không một module nên được kích hoạt tự động trên một diễn đàn hoặc trang cá nhân người dùng. Nếu module nên được kích hoạt, chọn "Luôn luôn kích hoạt".',
    'Module path %path% is not writeable!' => 'Đường dẫn module %path% không writeable!',
    'Save' => 'Lưu',
    'Spaces' => 'Các diễn đàn',
    'Users' => 'Người dùng',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => '',
    'Module deactivation in progress. This process may take a moment.' => '',
    'Module uninstall in progress. This process may take a moment.' => '',
    'Not available' => '',
    'Space default state' => '',
    'The module is currently being used by {nbContainers} users or spaces. If you change its availability, all content created with the module will be lost. Proceed?' => '',
    'Uninstallation of this module has not been completed yet. It will be removed in a few minutes.' => '',
    'User default state' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/vi/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Set as default module',
    'Always activated' => 'Luôn luôn kích hoạt',
    'Could not find requested module!' => 'Không thể tìm thấy module!',
    'Deactivated' => 'Hủy kích hoạt',
    'Enable module...' => 'Kích hoạt module...',
    'Enabled' => 'Đã được kích hoạt',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Ở đây bạn có thể chọn có hay không một module nên được kích hoạt tự động trên một diễn đàn hoặc trang cá nhân người dùng. Nếu module nên được kích hoạt, chọn "Luôn luôn kích hoạt".',
    'Module path %path% is not writeable!' => 'Đường dẫn module %path% không writeable!',
    'Save' => 'Lưu',
    'Spaces' => 'Các diễn đàn',
    'Users' => 'Người dùng',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => '',
    'Disable Module' => '',
    'Disabling the <strong>{moduleName}</strong> module will permanently delete <strong>all</strong> module-related content.' => '',
    'Module deactivation in progress. This process may take a moment.' => '',
    'Module uninstall in progress. This process may take a moment.' => '',
    'Not available' => '',
    'Space default state' => '',
    'The module is currently being used by {nbContainers} users or spaces. If you change its availability, all content created with the module will be lost. Proceed?' => '',
    'Uninstall Module' => '',
    'Uninstallation of this module has not been completed yet. It will be removed in a few minutes.' => '',
    'Uninstalling the <strong>{moduleName}</strong> module will permanently delete <strong>all</strong> module-related content.' => '',
    'User default state' => '',
];
